pub struct FsBlobStore { /* private fields */ }Expand description
Filesystem-backed blob store implementing hashtree’s Store trait.
Stores blobs in a 256-way sharded directory structure using the first 2 hex characters of the hash as the directory prefix. Supports storage limits with mtime-based FIFO eviction and pinning.
Implementations
Sourceimpl FsBlobStore
impl FsBlobStore
Sourcepub fn new<P: AsRef<Path>>(path: P) -> Result<Self, StoreError>
pub fn new<P: AsRef<Path>>(path: P) -> Result<Self, StoreError>
Create a new filesystem blob store at the given path.
Creates the directory if it doesn’t exist.
Sourcepub fn with_max_bytes<P: AsRef<Path>>(
path: P,
max_bytes: u64,
) -> Result<Self, StoreError>
pub fn with_max_bytes<P: AsRef<Path>>( path: P, max_bytes: u64, ) -> Result<Self, StoreError>
Create a new store with a maximum size limit
Sourcepub fn put_sync(&self, hash: Hash, data: &[u8]) -> Result<bool, StoreError>
pub fn put_sync(&self, hash: Hash, data: &[u8]) -> Result<bool, StoreError>
Sync put operation.
Sourcepub fn delete_sync(&self, hash: &Hash) -> Result<bool, StoreError>
pub fn delete_sync(&self, hash: &Hash) -> Result<bool, StoreError>
Sync delete operation.
Sourcepub fn stats(&self) -> Result<FsStats, StoreError>
pub fn stats(&self) -> Result<FsStats, StoreError>
Get storage statistics.