FsBlobStore

Struct FsBlobStore 

pub struct FsBlobStore { /* private fields */ }
Filesystem-backed blob store implementing hashtree’s Store trait.

Stores blobs in a 256-way sharded directory structure using the first 2 hex characters of the hash as the directory prefix.

Implementations

Source

impl FsBlobStore

pub fn new<P: AsRef<Path>>(path: P) -> Result<Self, StoreError>

Create a new filesystem blob store at the given path.

Creates the directory if it doesn’t exist.

pub fn put_sync(&self, hash: Hash, data: &[u8]) -> Result<bool, StoreError>

Sync put operation.

pub fn get_sync(&self, hash: &Hash) -> Result<Option<Vec<u8>>, StoreError>

Sync get operation.

pub fn exists(&self, hash: &Hash) -> bool

Check if a hash exists.

pub fn delete_sync(&self, hash: &Hash) -> Result<bool, StoreError>

Sync delete operation.

pub fn list(&self) -> Result<Vec<Hash>, StoreError>

List all hashes in the store.

pub fn stats(&self) -> Result<FsStats, StoreError>

Get storage statistics.